# 1.1 (15 Oct 2022)
## Changes
- add changelog
- fix multiple call imported function error
- add ability to get return from import function
- add debug logs
- fix section create bug
- add common errors note
- PyPi structure

# 1.0
Public release
